@@ -480,5 +480,8 @@ void background_job(int num);
 void tmpfile_all_sweep();
 void tmpfile_sweep();
 
+extern vector_obj* gStackTraceFName;
+extern vector_obj* gStackTraceLineNum;
+    // åե졼εϿ
 
 #endif
